@@ -235,9 +235,14 @@ impl Service<BoxRequest> for Wasm {
                 if check_spec_version
                     && hrpc_version
                         .as_ref()
-                        .map_or(false, |v| v == HRPC_SPEC_VERSION)
+                        .map_or(false, |v| v.trim() == HRPC_SPEC_VERSION)
                         .not()
                 {
+                    tracing::debug!(
+                        "incompatible spec version {:?} (ours is {})",
+                        hrpc_version,
+                        HRPC_SPEC_VERSION
+                    );
                     return Err(ClientError::IncompatibleSpecVersion.into());
                 }
 
